<?php
namespace Planejamento\Entities;
use Geral\Util\DateUtil;
use Setforms2\Shared\Registry;
use Geral\Util\Ambiente;

class Relpratemb extends Base\Relpratemb
{

    /**
     * Save da Visualização Embalagem por Prato
     * com nenhuma embalagem marcada salvando somente a embalagem com a linha Ativa
     * @param $linhas
     * @param $cdcontainer
     *
     * @return null
     */
    public static function saveRelPratEmb ($linhas, $cdcontainer)
    {
        $connection = Registry::getEntityManager();
        $connection->beginTransaction();

        foreach ($linhas as $registro) {
            if ($registro['VRQTDEPRATEMB']<=0) {
                tk_abort(tk_get_message_by_name('msg_winPla047_qtd_maior_zero'));
            }
            /**
             * @var \Planejamento\Entities\Relpratemb $relpratemb
             */
            $relpratemb = \Planejamento\Entities\Relpratemb::getObjectByWhere('CDFILAUXPRAT = ? AND CDPRATO = ? AND CDCONTAINER = ?', array($registro['CDFILAUXPRAT'], $registro['CDPRATO'], $cdcontainer));

            if (empty($relpratemb)) {
                $relpratemb = new Relpratemb();

                $relpratemb->setCdfilauxprat($registro['CDFILAUXPRAT']);
                $relpratemb->setCdprato($registro['CDPRATO']);
                $relpratemb->setCdcontainer($cdcontainer);
            }

            $relpratemb->setVrqtdepratemb($registro['VRQTDEPRATEMB']);
            // AUDITORIA
            $relpratemb->setDtinclusao(DateUtil::getDataAtual());
            $relpratemb->setDtultatu(DateUtil::getDataAtual());
            $relpratemb->setNrorg(Ambiente::getNrorg());
            $relpratemb->setNrorginclusao(Ambiente::getNrorg());
            $relpratemb->setCdoperinclusao(Ambiente::getCdOperador());
            $relpratemb->setNrorgultatu(Ambiente::getNrorg());
            $relpratemb->setCdoperultatu(Ambiente::getCdOperador());
            $relpratemb->persist();
        }

        $connection->flush();
        $connection->commit();
    }

    /**
     * Save da Visualização Embalagem por prato
     * com embalagens marcadas salvando de acordo com as marcadas
     * @param $linhasMarcadas
     * @param $linhas
     *
     * @return null
     */
    public static function saveRelPratEmbSelecionados ($linhasMarcadas, $linhas)
    {
        $connection = Registry::getEntityManager();
        $connection->beginTransaction();

        foreach ($linhasMarcadas as $registro) {
            foreach ($linhas as $prato) {
                /**
                 * Entidade RELPRATEMB
                 * @var \Planejamento\Entities\Relpratemb $relpratemb
                 */
                $relpratemb = Relpratemb::getObjectByWhere('CDCONTAINER = ? AND CDPRATO = ?', array($registro['CDCONTAINER'], $prato['CDPRATO']));

                if ($prato['VRQTDEPRATEMB']<=0) {
                    tk_abort(tk_get_message_by_name('msg_winPla047_qtd_maior_zero'));
                }
                if (empty($relpratemb)) {
                    $relpratemb = new Relpratemb();

                    $relpratemb->setCdfilauxprat($prato['CDFILAUXPRAT']);
                    $relpratemb->setCdprato($prato['CDPRATO']);
                    $relpratemb->setCdcontainer($registro['CDCONTAINER']);
                }
                $relpratemb->setVrqtdepratemb($prato['VRQTDEPRATEMB']);
                // AUDITORIA
                $relpratemb->setDtinclusao(DateUtil::getDataAtual());
                $relpratemb->setDtultatu(DateUtil::getDataAtual());
                $relpratemb->setNrorg(Ambiente::getNrorg());
                $relpratemb->setNrorginclusao(Ambiente::getNrorg());
                $relpratemb->setCdoperinclusao(Ambiente::getCdOperador());
                $relpratemb->setNrorgultatu(Ambiente::getNrorg());
                $relpratemb->setCdoperultatu(Ambiente::getCdOperador());
                $relpratemb->persist();
            }

        }

        $connection->flush();
        $connection->commit();
    }

    /**
     * Save da visualização Embalagens por Prato de acordo com o prato da linha ativa
     * @param $linhas
     * @param $prato
     * @param $cdfilauxprat
     *
     * @return null
     */
    public static function saveEmbPorPrato ($linhas, $prato, $cdfilauxprat)
    {
        $connection = Registry::getEntityManager();
        $connection->beginTransaction();

        foreach ($linhas as $registro) {
            if ($registro['VRQTDEPRATEMB']<=0) {
                tk_abort(tk_get_message_by_name('msg_winPla047_qtd_maior_zero'));
            }
            /**
             * @var \Planejamento\Entities\Relpratemb $relpratemb
             */
            $relpratemb = \Planejamento\Entities\Relpratemb::getObjectByWhere('CDFILAUXPRAT = ? AND CDPRATO = ? AND CDCONTAINER = ?', array($cdfilauxprat, $prato, $registro['CDCONTAINER']));

            if (empty($relpratemb)) {
                $relpratemb = new Relpratemb();

                $relpratemb->setCdfilauxprat($cdfilauxprat);
                $relpratemb->setCdprato($prato);
                $relpratemb->setCdcontainer($registro['CDCONTAINER']);
            }

            $relpratemb->setVrqtdepratemb($registro['VRQTDEPRATEMB']);
            // AUDITORIA
            $relpratemb->setDtinclusao(DateUtil::getDataAtual());
            $relpratemb->setDtultatu(DateUtil::getDataAtual());
            $relpratemb->setNrorg(Ambiente::getNrorg());
            $relpratemb->setNrorginclusao(Ambiente::getNrorg());
            $relpratemb->setCdoperinclusao(Ambiente::getCdOperador());
            $relpratemb->setNrorgultatu(Ambiente::getNrorg());
            $relpratemb->setCdoperultatu(Ambiente::getCdOperador());
            $relpratemb->persist();
        }

        $connection->flush();
        $connection->commit();
    }

    /**
     * @param $linhasMarcadas
     * @param $linhas
     *
     * @return null
     */
    public static function saveEmbPorPratoSelecionado ($linhasMarcadas, $linhas)
    {
        $connection = Registry::getEntityManager();
        $connection->beginTransaction();

        foreach ($linhasMarcadas as $prato) {
            foreach ($linhas as $embalagem) {
                /**
                 * Entidade RELPRATEMB
                 * @var \Planejamento\Entities\Relpratemb $relpratemb
                 */
                $relpratemb = Relpratemb::getObjectByWhere('CDPRATO = ? AND CDCONTAINER = ?', array($prato['CDPRATO'], $embalagem['CDCONTAINER']));

                if ($embalagem['VRQTDEPRATEMB']<=0) {
                    tk_abort(tk_get_message_by_name('msg_winPla047_qtd_maior_zero'));
                }
                if (empty($relpratemb)) {
                    $relpratemb = new Relpratemb();

                    $relpratemb->setCdfilauxprat($prato['CDFILAUXPRAT']);
                    $relpratemb->setCdprato($prato['CDPRATO']);
                    $relpratemb->setCdcontainer($embalagem['CDCONTAINER']);
                }
                $relpratemb->setVrqtdepratemb($embalagem['VRQTDEPRATEMB']);
                // AUDITORIA
                $relpratemb->setDtinclusao(DateUtil::getDataAtual());
                $relpratemb->setDtultatu(DateUtil::getDataAtual());
                $relpratemb->setNrorg(Ambiente::getNrorg());
                $relpratemb->setNrorginclusao(Ambiente::getNrorg());
                $relpratemb->setCdoperinclusao(Ambiente::getCdOperador());
                $relpratemb->setNrorgultatu(Ambiente::getNrorg());
                $relpratemb->setCdoperultatu(Ambiente::getCdOperador());
                $relpratemb->persist();
            }

        }

        $connection->flush();
        $connection->commit();
    }
}